@@ -1,8 +1,12 @@
+import configparser
 import datetime
+import importlib
 import importlib.resources
+import inspect
 import ipaddress
 import json
 import math
+import os
 import re
 import zoneinfo
 from collections.abc import MutableMapping, MutableSequence
@@ -11,7 +15,17 @@ from typing import Any, Callable, Optional, TypeVar, Union
 import lxml.etree
 import lxml.objectify
 
+_CONFIG_FILE = os.path.expanduser("~/qualysapi.conf")
+config = configparser.ConfigParser()
+config.read(_CONFIG_FILE)
+
 URLS = json.load(importlib.resources.files("qualyspy").joinpath("urls.json").open())
+DB_HOST = config["POSTGRESQL"]["host"]
+DB_NAME = config["POSTGRESQL"]["db_name"]
+DB_USER = config["POSTGRESQL"]["user"]
+DB_PASSWORD = config["POSTGRESQL"]["password"]
+
+E_URL = f"postgresql://{DB_USER}:{DB_PASSWORD}@{DB_HOST}/{DB_NAME}"
 
 
 def ips_to_qualys_format(
@@ -154,7 +168,7 @@ def remove_nones_from_dict(d: MutableMapping[str, Optional[str]]) -> dict[str, s
 def _apply_funcmap(
     tag: str, funcmap: MutableMapping[str, Callable[[str], Any]], element_text: str
 ) -> Any:
-    if tag in funcmap and funcmap[tag] is not None:
+    if tag in funcmap:
         return funcmap[tag](element_text)
     else:
         return element_text
@@ -424,3 +438,64 @@ class Filter:
 
     def __call__(self) -> dict[str, str]:
         return {"field": self.field, "operator": self.operator, "value": self.value}
+
+
+def to_camel(string: str) -> str:
+    return "".join(word.capitalize() for word in string.split("_"))
+
+
+def to_lower_camel(string: str) -> str:
+    if len(string) >= 1:
+        pascal_string = to_camel(string)
+        return pascal_string[0].lower() + pascal_string[1:]
+    return string.lower()
+
+
+_D = TypeVar("_D")
+re_classname = re.compile(r"(qualyspy[\w._]*)")
+re_sa_class = re.compile(r"sqlalchemy.orm")
+
+
+def _get_cls_inst_from_annot(mapped_cls: str) -> Any:
+    m = re_classname.search(mapped_cls)
+    if m is not None:
+        child_cls_strs = m.group(1).split(".")
+        child_cls_package = ".".join(child_cls_strs[:-1])
+        mod = importlib.import_module(child_cls_package)
+        child_cls = getattr(mod, child_cls_strs[-1])
+        return child_cls
+    else:
+        if re_sa_class.search(mapped_cls):
+            return None
+        else:
+            raise ValueError("Annotation is not a Mapped class.")
+
+
+def to_orm_object(
+    obj: dict[str, Any],
+    out_cls: type[_D],
+) -> _D:
+    annots = inspect.get_annotations(out_cls)
+    for k, v in obj.items():
+        if isinstance(v, dict):
+            mapped_cls = str(annots[k])
+            child_cls = _get_cls_inst_from_annot(mapped_cls)
+            if child_cls is None:
+                continue
+            obj[k] = to_orm_object(v, child_cls)
+        elif isinstance(v, list) and len(v) > 0:
+            mapped_cls = str(annots[k])
+            child_cls = _get_cls_inst_from_annot(mapped_cls)
+            if child_cls is None:
+                continue
+            if isinstance(v[0], dict):
+                for i in range(len(v)):
+                    v[i] = to_orm_object(v[i], child_cls)
+            else:
+                child_annots = inspect.get_annotations(child_cls)
+                param = next(iter(child_annots))
+                for i in range(len(v)):
+                    bind = {param: v[i]}
+                    obj[k][i] = child_cls(**bind)
+
+    return out_cls(**obj)
